@@ -241,7 +241,7 @@ seahorse_gedit_show_error (const gchar *heading, GError *error)
                     error->message ? error->message : "", NULL);
     
     dlg = gtk_message_dialog_new_with_markup (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR,
-                                              GTK_BUTTONS_CLOSE, t);
+                                              GTK_BUTTONS_CLOSE, t, NULL);
     g_free (t);
     
     gtk_dialog_run (GTK_DIALOG (dlg));
